@@ -10,7 +10,11 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <sodium.h>
+#ifdef LIBZODIUM
+#    include "zodium.h"
+#else
+#    include <sodium.h>
+#endif
 
 #include "base64.h"
 #include "get_line.h"
@@ -289,6 +293,7 @@ pubkey_load(const char *pk_file, const char *pubkey_s)
     exit_msg("A public key is required");
 }
 
+#ifndef VERIFY_ONLY
 static void
 seckey_compute_chk(unsigned char chk[crypto_generichash_BYTES], const SeckeyStruct *seckey_struct)
 {
@@ -302,7 +307,6 @@ seckey_compute_chk(unsigned char chk[crypto_generichash_BYTES], const SeckeyStru
     crypto_generichash_final(&hs, chk, sizeof seckey_struct->keynum_sk.chk);
 }
 
-#ifndef VERIFY_ONLY
 static void
 decrypt_key(SeckeyStruct *const seckey_struct, unsigned char chk[crypto_generichash_BYTES])
 {
@@ -461,9 +465,9 @@ verify(PubkeyStruct *pubkey_struct, const char *message_file, const char *sig_fi
     if (memcmp(sig_struct->keynum, pubkey_struct->keynum_pk.keynum, sizeof sig_struct->keynum) !=
         0) {
         fprintf(stderr,
-                "Signature key id in %s is %" PRIX64
+                "Signature key id in %s is %016" PRIX64
                 "\n"
-                "but the key id in the public key is %" PRIX64 "\n",
+                "but the key id in the public key is %016" PRIX64 "\n",
                 sig_file, le64_load(sig_struct->keynum),
                 le64_load(pubkey_struct->keynum_pk.keynum));
         exit(1);
@@ -662,7 +666,7 @@ write_pk_file(const char *pk_file, const PubkeyStruct *pubkey_struct)
     if ((fp = fopen(pk_file, "w")) == NULL) {
         exit_err(pk_file);
     }
-    xfprintf(fp, COMMENT_PREFIX "minisign public key %" PRIX64 "\n",
+    xfprintf(fp, COMMENT_PREFIX "minisign public key %016" PRIX64 "\n",
              le64_load(pubkey_struct->keynum_pk.keynum));
     xfput_b64(fp, (const unsigned char *) (const void *) pubkey_struct, sizeof *pubkey_struct);
     xfclose(fp);
@@ -829,20 +833,28 @@ main(int argc, char **argv)
 #ifndef VERIFY_ONLY
     char *sk_file = sig_default_skfile();
 #endif
-    const char   *sig_file        = NULL;
-    const char   *message_file    = NULL;
-    const char   *comment         = NULL;
-    const char   *pubkey_s        = NULL;
-    const char   *trusted_comment = NULL;
-    unsigned char opt_seen[16]    = { 0 };
+    const char *sig_file     = NULL;
+    const char *message_file = NULL;
+#ifndef VERIFY_ONLY
+    const char *comment = NULL;
+#endif
+    const char *pubkey_s = NULL;
+#ifndef VERIFY_ONLY
+    const char *trusted_comment = NULL;
+#endif
+    unsigned char opt_seen[16] = { 0 };
     int           opt_flag;
-    int           quiet           = 0;
-    int           output          = 0;
-    int           force           = 0;
-    int           allow_legacy    = 1;
-    int           sign_legacy     = 0;
-    int           unencrypted_key = 0;
-    Action        action          = ACTION_NONE;
+    int           quiet  = 0;
+    int           output = 0;
+#ifndef VERIFY_ONLY
+    int force = 0;
+#endif
+    int allow_legacy = 1;
+#ifndef VERIFY_ONLY
+    int sign_legacy     = 0;
+    int unencrypted_key = 0;
+#endif
+    Action action = ACTION_NONE;
 
     while ((opt_flag = getopt(argc, argv, getopt_options)) != -1) {
         switch (opt_flag) {
@@ -891,9 +903,11 @@ main(int argc, char **argv)
         case 'H':
             allow_legacy = 0;
             break;
+#ifndef VERIFY_ONLY
         case 'l':
             sign_legacy = 1;
             break;
+#endif
         case 'm':
             message_file = optarg;
             break;
